@@ -1,5 +1,6 @@
 
-library(mapmisc)
+library('mapmisc')
+
 myraster = raster(matrix(0,10,10),xmn=8,xmx=18,ymn=0,ymx=10, 
 		crs="+proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0")
 values(myraster) = seq(0,1,len=ncell(myraster))
@@ -10,6 +11,10 @@ myPoints = SpatialPoints(myraster, proj4string=CRS(proj4string(myraster)))[
 plot(myraster)
 points(myPoints)
 
+# only do the following if rgdal is available
+if(require('rgdal', quietly=TRUE)) {
+	
+
 utmproj = "+proj=utm +zone=32" 
 myrasterUTM = projectRaster(myraster, crs=utmproj)
 myPointsUTM = spTransform(myPoints, CRS(utmproj))
@@ -102,3 +107,4 @@ if(exists("nsl", where="package:utils")) {
 	
 	}
 }		
+}
\ No newline at end of file
